@@ -1,6 +1,7 @@
-from je_editor.tkinter_ui.editor_main_ui.tkinter_editor import EditorMain
 # start editor
-from je_editor.tkinter_ui.editor_main_ui.tkinter_editor import start_editor
+from je_editor.start_editor import start_editor
+# Editor
+from je_editor.pyside_ui.main_ui.editor_main_ui.main_editor import EditorMain
 # Exceptions
 from je_editor.utils.exception.exceptions import JEditorException
 from je_editor.utils.exception.exceptions import JEditorExecException
@@ -10,16 +11,12 @@ from je_editor.utils.exception.exceptions import JEditorOpenFileException
 from je_editor.utils.exception.exceptions import JEditorContentFileException
 from je_editor.utils.exception.exceptions import JEditorCantFindLanguageException
 from je_editor.utils.exception.exceptions import JEditorJsonException
-# file
-from je_editor.utils.file.open.open_file import open_file
-from je_editor.utils.file.save.save_file import save_file
+
 
 __all__ = [
-    "EditorMain",
-    "start_editor",
+    "start_editor", "EditorMain",
     "JEditorException", "JEditorExecException",
     "JEditorRunOnShellException", "JEditorSaveFileException",
     "JEditorOpenFileException", "JEditorContentFileException",
     "JEditorCantFindLanguageException", "JEditorJsonException",
-    "open_file", "save_file"
 ]
